@@ -16,6 +16,7 @@
 
 import types
 
+from pymongo.connection import Connection as PyMongo_Connection
 from pymongo.son import SON
 
 ASCENDING = 1
@@ -30,9 +31,12 @@ SLOW_ONLY = 1
 ALL = 2
 """Profile all operations."""
 
-version = "0.10"
+version = "0.10.1"
 """Current version of PyMongo."""
 
+Connection = PyMongo_Connection
+"""Alias for pymongo.connection.Connection."""
+
 def _index_list(key_or_list, direction):
     """Helper to generate a list of (key, direction) pairs.
 
